@@ -124,9 +124,9 @@ impl<'a> ShaderStage<'a> {
                     s_type: StructureType::PIPELINE_SHADER_STAGE_CREATE_INFO,
                     p_next: self.shader_stage_p_next,
                     flags: self.shader_stage_flags,
-                    stage: if path.contains("vert.spv") || path.contains(".vs") {
+                    stage: if path.contains(".vert.spv") || path.contains(".vs") {
                         ShaderStageFlags::VERTEX
-                    } else if path.contains("frag.spv") || path.contains(".fs") {
+                    } else if path.contains(".frag.spv") || path.contains(".fs") {
                         ShaderStageFlags::FRAGMENT
                     } else {
                         panic!("Failed to define shader type!")
@@ -146,9 +146,9 @@ fn create_shader_modules(
     flags: ShaderModuleCreateFlags,
     p_next: *const c_void,
 ) -> Vec<ShaderModule> {
-    let spv_files_dir =
+    let compiled_shader_path =
         read_dir(dir_path).unwrap_or_else(|_| panic!("Failed to find spv file at {:?}", dir_path));
-    let files_path_buf: Vec<PathBuf> = spv_files_dir
+    let files_path_buf: Vec<PathBuf> = compiled_shader_path
         .into_iter()
         .filter(|file_name| {
             let file_name = file_name
